from . import arrays_updaters

imo236tidalDataBitlengths = (27, 28, 5, 6, 5, 6, 9, 7)
imo236tidalDataTypes = ("I4", "I4", "u", "u", "u", "u", "u", "U1")
class imo236_tidal():
    """Struktura danych dla tablicy informacji o pływach
    """
    def __init__(self, dataParts):
        """Inicjalizuje pola w strukturze danych dla tablicy informacji o pływach

        Args:
            dataParts (list): dane typu prostego
        """
        self.type = "Tidal info"
        self.dataParts = dataParts
        self.fields = [
            "\tLatitude", "\tLongitude", "\tFrom UTC Hour", "\tFrom UTC Minute", "\tTo UTC Hour", "\tTo UTC Minute", "\tCurrent Direction Predicted", "\tCurrent Speed Predicted"
            ]
        arrays_updaters.updateImo236Tidal(self)

copDataBitlengths = (2, 25, 24, 3, 12, 18)
copDataTypes = ("u", "I3", "I3", "u", "u", "x")
class circle_or_point():
    """Struktura danych dla tablicy informacji o kształcie obszaru - typ Circle or Point
    """
    def __init__(self, dataParts):
        """Inicjalizuje pola w strukturze danych dla tablicy informacji o kształcie obszaru - typ Circle or Point

        Args:
            dataParts (list): dane typu prostego
        """
        self.type = "Circle or point"
        self.dataParts = dataParts
        self.fields = [
            "\tScale factor", "\tLongitude", "\tLatitude", "\tPrecision", "\tRadius"
            ]
        arrays_updaters.updateCircleOrPoint(self)

rectangleDataBitlengths = (2, 25, 24, 3, 8, 8, 9, 5)
rectangleDataTypes = ("u", "I3", "I3", "u", "u", "u", "u", "x")
class rectangle():
    """Struktura danych dla tablicy informacji o kształcie obszaru - typ Rectangle
    """
    def __init__(self, dataParts):
        """Inicjalizuje pola w strukturze danych dla tablicy informacji o kształcie obszaru - typ Rectangle

        Args:
            dataParts (list): dane typu prostego
        """
        self.type = "Rectangle"
        self.dataParts = dataParts
        self.fields = [
            "\tScale factor", "\tLongitude", "\tLatitude", "\tPrecision", "\tE dimension", "\tN dimension", "\tOrientation"
            ]
        arrays_updaters.updateRectangle(self)

sectorDataBitlengths = (2, 25, 24, 3, 12, 9, 9)
sectorDataTypes = ("u", "I3", "I3", "u", "u", "u", "u")
class sector():
    """Struktura danych dla tablicy informacji o kształcie obszaru - typ Sector
    """
    def __init__(self, dataParts):
        """Inicjalizuje pola w strukturze danych dla tablicy informacji o kształcie obszaru - typ Sector

        Args:
            dataParts (list): dane typu prostego
        """
        self.type = "Sector"
        self.dataParts = dataParts
        self.fields = [
            "\tScale factor", "\tLongitude", "\tLatitude", "\tPrecision", "\tRadius", "\tLeft boundary", "\tRight boundary"
            ]
        arrays_updaters.updateSector(self)

# UWAGA: kształt z 4 zestawami danych punktów odniesienia
polylineDataBitlengths = (2,)
polylineDataTypes = ("u",)
class polyline():
    """Struktura danych dla tablicy informacji o kształcie obszaru - typ Polyline
    """
    def __init__(self, scale, waypoints):
        """Inicjalizuje pola w strukturze danych dla tablicy informacji o kształcie obszaru - typ Polyline

        Args:
            scale (unsigned int): wspolczynnik skali będący potęgą 10; domyślnie przyjmuje wartość 10^0=1
            waypoints ([type]): [description]
        """
        self.type = "Polyline"
        self.scale = scale
        self.waypoints = waypoints
        self.fields = [
            "\tScale factor"
            ]
        arrays_updaters.updatePolyline(self)

polylineWaypointDataBilengths = (10, 10)
polylineWaypointDataTypes = ("u", "u")
class polyline_waypoint():
    """Struktura danych dla tablicy punktów kształtu obszaru o typie Polyline
    """
    def __init__(self, dataParts):
        """Inicjalizuje pola w strukturze danych dla tablicy punktów kształtu obszaru o typie Polyline

        Args:
            dataParts (list): dane typu prostego
        """
        self.type = "\tPolyline waypoint"
        self.dataParts = dataParts
        self.fields = [
            "\t\tBearing", "\t\tDistance"
            ]
        arrays_updaters.updatePolylineWaypoint(self)

# UWAGA: kształt z 4 zestawami danych wierzchołków
polygonDataBitlengths = (2,)
polygonDataTypes = ("u",)
class polygon():
    """Struktura danych dla tablicy informacji o kształcie obszaru - typ Polygon
    """
    def __init__ (self, scale, vertices):
        """Inicjalizuje pola w strukturze danych dla tablicy informacji o kształcie obszaru - typ Polygon

        Args:
            scale (unsigned int): wspolczynnik skali będący potęgą 10; domyślnie przyjmuje wartość 10^0=1
            vertices (array): tablica danych o wierzcholkach 
        """
        self.type = "Polygon"
        self.scale = scale
        self.vertices = vertices
        self.fields = [
            "\tScale factor"
            ]
        arrays_updaters.updatePolygon(self)

verticesDataBilengths = (10, 10)
verticesDataTypes = ("u", "u")
class polygon_vertices():
    """Struktura danych dla tablicy wierzchołków kształtu obszaru o typie Polygon
    """
    def __init__(self, dataParts):
        """Inicjalizuje pola w strukturze danych dla tablicy wierzchołków kształtu obszaru o typie Polygon

        Args:
            dataParts (list): dane typu prostego
        """
        self.type = "\tPolygon Vertex"
        self.dataParts = dataParts
        self.fields = [
            "\t\tBearing", "\t\tDistance"
            ]
        arrays_updaters.updatePolygonVertices(self)

# to również jest typ kształtu dla wiadomości typu 6_6
associatedTextBitlengths = (84)
associatedTextDataTypes = ("t",)
class associated_text():
    """Struktura danych dla tablicy informacji o kształcie obszaru - typ Associated Text
    """
    def __init__(self, text):
        """Inicjalizuje pola w strukturze danych dla tablicy informacji o kształcie obszaru - typ Associated Text

        Args:
            text (str): string o długości 14 znaków
        """
        self.type = "Associated text"     
        self.text = text
        self.fields = [
            "\tText"
            ]
        arrays_updaters.updateAssociatedText(self)

cargoDataBitlengths = (4, 13)
cargoDataTypes = ("e", "u")
class cargo():
    """Struktura danych dla tablicy informacji o typie ładunku
    """
    def __init__(self, dataParts):
        """Inicjalizuje pola w strukturze danych dla tablicy informacji o typie ładunku

        Args:
            dataParts (list): dane typu prostego
        """
        self.type = "Cargo"
        self.dataParts = dataParts
        self.fields = [
            "\tCargo code", "\tCargo subtype"
            ]
        arrays_updaters.updateCargo(self)

waypointDataBilengths = (28, 27)
waypointDataTypes = ("I4", "I4")
class waypoint():
    """Struktura danych dla tablicy informacji o punktach nawigacyjnych
    """
    def __init__(self, dataParts):
        """Inicjalizuje pola w strukturze danych dla tablicy informacji o punktach nawigacyjnych

        Args:
            dataParts (list): dane typu prostego
        """
        self.type = "Waypoint"
        self.dataParts = dataParts
        self.fields = [
            "\tLongitude", "\tLatitude"
            ]
        arrays_updaters.updateWaypoint(self)

imo289tidalDataBitlengths = (25, 24, 5, 6, 5, 6, 9, 8)
imo289tidalDataTypes = ("I3", "I3", "u", "u", "u", "u", "u", "U1")
class imo289_tidal():
    """Struktura danych dla tablicy informacji o pływach
    """
    def __init__(self, dataParts):
        """Inicjalizuje pola w strukturze danych dla tablicy informacji o pływach

        Args:
            dataParts (list): dane typu prostego
        """
        self.type = "Tidal"
        self.dataParts = dataParts
        self.fields = [
            "\tLongitude", "\tLatitude", "\tFrom UTC Hour", "\tFrom UTC Minute", "\tTo UTC Hour", "\tTo UTC Minute", 
            "\tCurrent Direction Predicted", "\tCurrent Speed Predicted"
            ]
        arrays_updaters.updateImo289Tidal(self)

destinationMMSIDataBitlengths = (30, 2)
destinationMMSITypes = ("u", "u")
class destinationMMSI():
    """Struktura danych dla tablicy informacji o MMSI odbiorcy
    """
    def __init__(self, dataParts):
        """Inicjalizuje pola w strukturze danych dla tablicy informacji o MMSI odbiorcy

        Args:
            dataParts (list): dane typu prostego
        """
        self.type = "Destination MMSI"
        self.dataParts = dataParts
        self.fields = ["\tMMSI number", "\tSequence for MMSI"]
        arrays_updaters.updateDestinationMMSI(self)

# UWAGA: drugie pole (id) jest typu unsigned int (jak w krotce) JEŚLI type jest 0 albo 1
# jeśli type = 2 albo 3, to id jest typu "t"
targetDataBitlengths = (2, 42, 4, 23, 25, 9, 6, 10)
targetDataTypes = ("e", "u", "x", "I3", "I3", "u", "u", "u")
class target():
    """Struktura danych dla tablicy informacji o celu
    """
    def __init__(self, dataParts):
        """Inicjalizuje pola w strukturze danych dla tablicy informacji o celu

        Args:
            dataParts (list): dane typu prostego
        """
        self.type = "Target"
        self.dataParts = dataParts
        self.fields = [
            "\tIdentifier type", "\tTarget identifier", "\tLatitude", "\tLongitude", "\tCourse Over Ground", "\tTime Stamp", "\tSpeed Over Ground"
            ]
        arrays_updaters.updateTarget(self)

# UWAGA: pierwszym polem (dataParts[0]) jest typ raportu, który określa w jaki sposób powinna być
#   interpretowana zawartość ostatniego pola (payloadu z czujnika - ostatnie 85 bitów)
reportDataBitLengths = (4, 5, 5, 6, 7)
reportDataTypes = ("u", "u", "u", "u", "u")
class report():
    """Struktura danych dla tablicy informacji o typach odczytu czujnika
    """
    def __init__(self, dataParts, payload):
        """Inicjalizuje pola w strukturze danych dla tablicy informacji o typach odczytu czujnika

        Args:
            dataParts (list): dane typu prostego
            payload (data): dane właściwe z odczytu czujnika
        """
        self.type = "Report"
        self.dataParts = dataParts
        self.sensorPayload = payload
        self.fields = [
            "\tSensor Report Type", "\tDay (UTC)", "\tHour (UTC)", "\tMinute (UTC)", "\tSite ID"
            ]
        arrays_updaters.updateReport(self)

sitelocationDataBitlengths = (28, 27, 11, 4, 3, 12)
sitelocationDataTypes = ("I4", "I4", "u", "e", "e", "x")
class siteLocationPayload():
    """Struktura danych dla tablicy informacji o odczycie czujnika - typ Site Location
    """
    def __init__(self, dataParts):
        """Inicjalizuje pola w strukturze danych dla tablicy informacji o odczycie czujnika - typ Site Location

        Args:
            dataParts (list): dane typu prostego
        """
        self.type = "\tSite location"
        self.dataParts = dataParts
        self.fields = [
            "\t\tLongitude", "\t\tLatitude", "\t\tAltitude", "\t\tSensor owner", "\t\tData timeout"
            ]
        arrays_updaters.updateSiteLocationPayload(self)

stationidDataBitlengths = (84, 1)
stationidDataTypes = ("t", "x")
class stationIdPayload():
    """Struktura danych dla tablicy informacji o odczycie czujnika - typ Station ID
    """
    def __init__(self, dataParts):
        """Inicjalizuje pola w strukturze danych dla tablicy informacji o odczycie czujnika - typ Station ID

        Args:
            dataParts (list): dane typu prostego
        """
        self.type = "\tStation ID"
        self.dataParts = dataParts
        self.fields = [
            "\t\tName"
            ]
        arrays_updaters.updateStationIdPayload(self)

windDataBitLengths = (7,  7, 9, 9, 3, 7, 7, 9, 5, 5, 6, 8, 3)
windDataTypes = ("u", "u", "u", "u", "e", "u", "u", "u", "u", "u", "u", "u", "x")
class windPayload():
    """Struktura danych dla tablicy informacji o odczycie czujnika - typ Wind
    """
    def __init__(self, dataParts):
        """Inicjalizuje pola w strukturze danych tablicy informacji o odczycie czujnika - typ Wind

        Args:
            dataParts (list): dane typu prostego
        """
        self.type = "\tWind"
        self.dataParts = dataParts
        self.fields = [
            "\t\tAverage Wind Speed", "\t\tWind Gust", "\t\tWind Direction", "\t\tWind Gust Direction", "\t\tSensor Description", "\t\tForecast Wind Speed", 
            "\t\tForecast Wind Gust", "\t\tForecast Wind Direction", "\t\tDay (UTC)", "\t\tHour (UTC)", "\t\tMinute (UTC)", "\t\tForecast Duration"
            ]
        arrays_updaters.updateWindPayload(self)

waterlevelDataBitlnegths = (1, 16, 2, 5, 3, 1, 16, 5, 5, 6, 8, 17)
waterlevelDataTypes = ("b", "i", "u", "u", "e", "b", "i", "u", "u", "u", "u", "x")
class waterLevelPayload():
    """Struktura danych dla tablicy informacji o odczycie czujnika - typ Water Level
    """
    def __init__(self, dataParts):
        """Inicjalizuje pola w strukturze danych tablicy informacji o odczycie czujnika - typ Water Level

        Args:
            dataParts (list): dane typu prostego
        """
        self.type = "\tWater Level"
        self.dataParts = dataParts
        self.fields = [
            "\t\tWater Level Type", "\t\tWater Level", "\t\tWater Level Trend", "\t\tVertical Reference Datum", "\t\tSensor Description", 
            "\t\tForecast Water Level Type", "\t\tForecast Water Level", "\t\tDay (UTC)", "\t\tHour (UTC)", "\t\tMinute (UTC)", "\t\tDuration"
            ]
        arrays_updaters.updateWaterLevelPayload(self)

currentflow2dDataBitlenghts = (8, 9, 9, 8, 9, 9, 8, 9, 9, 3, 4)
currentflow2dDataTypes = ("U1", "u", "u", "U1", "u", "u", "U1", "u", "u", "e", "x")
class currentFlow2dPayload():
    """Struktura danych dla tablicy informacji o odczycie czujnika - typ Current Flow (2D)
    """
    def __init__ (self, dataParts):
        """Inicjalizuje pola w strukturze danych tablicy informacji o odczycie czujnika - typ Current Flow (2D)

        Args:
            dataParts (list): dane typu prostego
        """
        self.type = "\tCurrent Flow (2D)"
        self.dataParts = dataParts
        self.fields = [
            "\t\tCurrent Speed 1", "\t\tCurrent Direction 1", "\t\tMeasurement Depth 1", "\t\tCurrent Speed 2", "\t\tCurrent Direction 2",
            "\t\tMeasurement Depth 2", "\t\tCurrent Speed 3", "\t\tCurrent Direction 3", "\t\tMeasurement Depth 3", "\t\tSensor Description"
            ]
        arrays_updaters.updateCurrentFlow2dPayload(self)

currentflow3dDataBitlengths = (8, 8, 8, 9, 8, 8, 8, 9, 3, 16)
currentflow3dDataTypes = ("U1", "U1", "U1", "u", "U1", "U1", "U1", "u", "e", "x")
class currentFlow3dPayload():
    """Struktura danych dla tablicy informacji o odczycie czujnika - typ Current Flow (3D)
    """
    def __init__(self, dataParts):
        """Inicjalizuje pola w strukturze danych tablicy informacji o odczycie czujnika - typ Current Flow (3D)

        Args:
            dataParts (list): dane typu prostego
        """
        self.type = "\tCurrent flow (3D)"
        self.dataParts = dataParts
        self.fields = [
            "\t\tCurrent Vector component North (u) 1", "\t\tCurrent Vector component East (v) 1", "\t\tCurrent Vector component Up (z) 1", "\t\tMeasurement Depth 1",
            "\t\tCurrent Vector component North (u) 2", "\t\tCurrent Vector component East (v) 2", "\t\tCurrent Vector component Up (z) 2", "\t\tMeasurement Depth 2", "Sensor Description"
            ]
        arrays_updaters.updateCurrentFlow3dPayload(self)

horizontalcurrentDataBitlengths = (9, 7, 8, 9, 9, 9, 7, 8 ,9 ,9, 1)
horizontalcurrentDataTypes = ("u", "u", "U1", "u", "u", "u", "u", "U1", "u", "u", "x")
class horizontalCurrentFlowPayload():
    """Struktura danych dla tablicy informacji o odczycie czujnika - typ Horizontal Current Flow
    """
    def __init__ (self, dataParts):
        """Inicjalizuje pola w strukturze danych tablicy informacji o odczycie czujnika - typ Horizontal Current Flow

        Args:
            dataParts (list): dane typu prostego
        """
        self.type = "\tHorizontal current"
        self.dataParts = dataParts
        self.fields = [
            "\t\tCurrent Bearing 1", "\t\tCurrent Distance 1", "\t\tCurrent Speed 1", "\t\tCurrent Direction 1", "\t\tMeasurement Depth 1",
            "\t\tCurrent Bearing 2", "\t\tCurrent Distance 2", "\t\tCurrent Speed 2", "\t\tCurrent Direction 2", "\t\tMeasurement Depth 2"
            ]
        arrays_updaters.updateHorizontalCurrentFlowPayload(self)

seastateDataBitlengths = (8, 6, 9, 4, 3, 10, 7, 3, 8, 6, 9, 3, 9)
seastateDataTypes = ("U1", "u", "u", "u", "e", "U1", "U1", "e", "U1", "u", "u", "e", "U1")
class seaStatePayload():
    """Struktura danych dla tablicy informacji o odczycie czujnika - typ Sea State
    """
    def __init__ (self, dataParts):
        """Inicjalizuje pola w strukturze danych tablicy informacji o odczycie czujnika - typ Sea State

        Args:
            dataParts (list): dane typu prostego
        """
        self.type = "\tSea state"
        self.dataParts = dataParts
        self.fields = [
            "\t\tSwell Height", "\t\tSwell Period", "\t\tSwell Direction", "\t\tSea State", "\t\tSwell Sensor Description", "\t\tWater Temperature", 
            "\t\tWater Temperature Depth", "\t\tDepth Sensor Description", "\t\tWave Height", "\t\tWave Period", "\t\tWave Direction", 
            "\t\tWave Sensor Description", "\t\tSalinity"
            ]
        arrays_updaters.updateSeaStatePayload(self)
        
salinityDataBitlengths = (10, 10, 16, 9, 2, 3, 35)
salinityDataTypes = ("U1", "U1", "U1", "U1", "e", "e", "x")
class salinityPayload():
    """Struktura danych dla tablicy informacji o odczycie czujnika - typ Salinity
    """
    def __init__(self, dataParts):
        """Inicjalizuje pola w strukturze danych tablicy informacji o odczycie czujnika - typ Salinity

        Args:
            dataParts (list): dane typu prostego
        """
        self.type = "\tSalinity"
        self.dataParts = dataParts
        self.fields = [
            "\t\tWater Temperature", "\t\tConductivity", "\t\tWater Pressure", "\t\tSalinity", "\t\tSalinity Type", "\t\tSensor Description"
            ]
        arrays_updaters.updateSalinityPayload(self)

weatherDataBitlengths = (11, 3, 2, 8, 10, 3, 9, 2, 3, 9, 25)
weatherDataTypes = ("i", "e", "e", "U1", "i", "e", "u", "e", "e", "U1", "x")
class weatherPayload():
    """Struktura danych dla tablicy informacji o odczycie czujnika - typ Weather
    """
    def __init__(self, dataParts):
        """Inicjalizuje pola w strukturze danych tablicy informacji o odczycie czujnika - typ Weather

        Args:
            dataParts (list): dane typu prostego
        """
        self.type = "\tWeather"
        self.dataParts = dataParts
        self.fields = [
            "\t\tAir Temperature", "\t\tTemperature Sensor Type", "\t\tPrecipitation Type", "\t\tHorizontal Visibility", "\t\tDew Point", 
            "\t\tDewpoint Sensor Type", "\t\tAir Pressure", "\t\tPressure Tendency", "\t\tPressure Sensor Type", "\t\tSalinity"
            ]
        arrays_updaters.updateWeatherPayload(self)

airgapDataBitlengths = (13, 13, 2, 13, 5, 5, 6, 28)
airgapDataTypes = ("U1", "U1", "e", "U1", "u", "u", "u", "x")
class airGapPayload():
    """Struktura danych dla tablicy informacji o odczycie czujnika - typ Air Gap/Air Draft
    """
    def __init__(self, dataParts):
        """Inicjalizuje pola w strukturze danych tablicy informacji o odczycie czujnika - typ Air Gap/Air Draft

        Args:
            dataParts (list): dane typu prostego
        """
        self.type = "\tAir Gap/Air Draft"
        self.dataParts = dataParts
        self.fields = [
            "\t\tAir Draught", "\t\tAir Gap", "\t\tAir Gap Trend", "\t\tForecast Air Gap", "\t\tDay (UTC)", "\t\tHour (UTC)", "\t\tMinute (UTC)"
            ]
        arrays_updaters.updateAirGapPayload(self)

gaugeDataBitlengths = (11, 14)
gaugeDataTypes = ("u", "i")
class gauge():
    """Struktura danych dla tablicy informacji o pomiarach wskaźników
    """
    def __init__(self, dataParts):
        """Inicjalizuje pola w strukturze danych tablicy informacji o pomiarach wskaźników

        Args:
            dataParts (list): dane typu prostego
        """
        self.type = "Gauge"
        self.dataParts = dataParts
        self.fields = [
            "\tGauge ID", "\tWater Level"
            ]
        arrays_updaters.updateGauge(self)

reservedSlotDataBitlengths = (12, 4, 3, 11)
reservedSlotTypes = ("u", "u", "u", "u")
class reservedSlot():
    """Struktura danych dla tablicy zarezerwowanych slotów
    """
    def __init__(self, dataParts):
        """Inicjalizuje pola w strukturze danych dla tablicy zarezerwowanych slotów

        Args:
            dataParts (list): dane typu prostego
        """
        self.type = "Reserved slot"
        self.dataParts = dataParts
        self.fields = ["\tOffset number", "\tReserved slots", "\tTime-out", "\tIncrement"]
        arrays_updaters.updateReservedSlot(self)



arraysDataBitlengths = {
    1:imo236tidalDataBitlengths,        2:copDataBitlengths, 
    3:rectangleDataBitlengths,          4:sectorDataBitlengths, 
    5:polylineDataBitlengths,           6:polylineWaypointDataBilengths, 
    7:polygonDataBitlengths,            8:verticesDataBilengths, 
    9:associatedTextBitlengths,         10:cargoDataBitlengths,
    11:waypointDataBilengths,           12:imo289tidalDataBitlengths,
    13:destinationMMSIDataBitlengths,   14: targetDataBitlengths, 
    15:reportDataBitLengths,            16:sitelocationDataBitlengths,
    17:stationidDataBitlengths,         18:windDataBitLengths,
    19:waterlevelDataBitlnegths,        20:currentflow2dDataBitlenghts, 
    21:currentflow3dDataBitlengths,     22:horizontalcurrentDataBitlengths,
    23:seastateDataBitlengths,          24:salinityDataBitlengths,
    25:weatherDataBitlengths,           26:airgapDataBitlengths,
    27:gaugeDataBitlengths,             28:reservedSlotDataBitlengths
    }

arraysDataTypes = {
    1:imo236tidalDataTypes,             2:copDataTypes, 
    3:rectangleDataTypes,               4:sectorDataTypes,
    5:polylineDataTypes,                6:polylineWaypointDataTypes,
    7:polygonDataTypes,                 8:verticesDataTypes,# ?do którego typu 
    9:associatedTextDataTypes,          10:cargoDataTypes,  # ?gdzie associated data
    11:waypointDataTypes,               12:imo289tidalDataTypes,                
    13:destinationMMSITypes,            14:targetDataTypes,
    15:reportDataTypes,                 16:sitelocationDataTypes,
    17:stationidDataTypes,              18:windDataTypes,
    19:waterlevelDataTypes,             20:currentflow2dDataTypes,
    21:currentflow3dDataTypes,          22:horizontalcurrentDataTypes,
    23:seastateDataTypes,               24:salinityDataTypes,
    25:weatherDataTypes,                26:airgapDataTypes, 
    27:gaugeDataTypes,                  28:reservedSlotTypes
    }
    
    # 6_2  -> 1
    # 6_7  -> 2, 3, 4, 5, 6, 7, 8, 9 # 8 i 9 na czuja
    # 6_8  -> 10
    # 6_9  -> 11
    # 6_11 -> 12
    # 7    -> 13
    # 8_4  -> 14
    # 8_7  -> 2, 3, 4, 5, 6, 7, 8, 9 # 8 i 9 na czuja
    # 8_9  -> 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26
    # 8_10 -> 11
    # 8_15 -> 27
    # 20   -> 28
    
    