from . import enums
from . import updaters

def updateImo236Tidal(tidal):
    """Interpretuje zawartości pól dla tablicy informacji o pływach

    Args:
        tidal (imo236_tidal): struktura danych dla tablicy informacji o pływach
    """
    to_update_index = tidal.fields.index("\tLongitude")
    if tidal.dataParts[to_update_index] == 181:
        tidal.dataParts[to_update_index] = "N/A"
    elif tidal.dataParts[to_update_index] > 0:
        tidal.dataParts[to_update_index] = "{} minutes (E)".format(tidal.dataParts[to_update_index])
    elif tidal.dataParts[to_update_index] < 0:
        tidal.dataParts[to_update_index] = "{} minutes (W)".format(tidal.dataParts[to_update_index])

    to_update_index = tidal.fields.index("\tLatitude")
    if tidal.dataParts[to_update_index] == 91:
        tidal.dataParts[to_update_index] = "N/A"
    elif tidal.dataParts[to_update_index] > 0:
        tidal.dataParts[to_update_index] = "{} minutes (N)".format(tidal.dataParts[to_update_index])
    elif tidal.dataParts[to_update_index] < 0:
        tidal.dataParts[to_update_index] = "{} minutes (S)".format(tidal.dataParts[to_update_index]) 

    to_update_index = tidal.fields.index("\tFrom UTC Hour")
    if(tidal.dataParts[to_update_index]) == 24:
        tidal.dataParts[to_update_index] = "N/A"
    to_update_index = tidal.fields.index("\tFrom UTC Minute")
    if(tidal.dataParts[to_update_index]) == 60:
        tidal.dataParts[to_update_index] = "N/A"
    to_update_index = tidal.fields.index("\tTo UTC Hour")
    if(tidal.dataParts[to_update_index]) == 24:
        tidal.dataParts[to_update_index] = "N/A"
    to_update_index = tidal.fields.index("\tTo UTC Minute")
    if(tidal.dataParts[to_update_index]) == 60:
        tidal.dataParts[to_update_index] = "N/A"

    to_update_index = tidal.fields.index("\tCurrent Direction Predicted")
    if tidal.dataParts[to_update_index] == 360:
        tidal.dataParts[to_update_index] = "N/A"
    else:
        tidal.dataParts[to_update_index] = "{} deg".format(tidal.dataParts[to_update_index])

    to_update_index = tidal.fields.index("\tCurrent Speed Predicted")
    if tidal.dataParts[to_update_index] == 12.7:
        tidal.dataParts[to_update_index] = "N/A"
    else:
        tidal.dataParts[to_update_index] = "{} knots".format(tidal.dataParts[to_update_index])

def updateCargo(cargo):
    """Interpretuje zawartości pól dla tablicy informacji o typie ładunku

    Args:
        cargo (cargo): struktura danych dla tablicy informacji o typie ładunku
    """
    to_update_index = cargo.fields.index("\tCargo code")
    cargo.dataParts[to_update_index] = enums.cargoCodes[cargo.dataParts[to_update_index]]

    to_update_index = cargo.fields.index("\tCargo subtype")
    if cargo.dataParts[to_update_index] == 0:
        cargo.dataParts[to_update_index] = "N/A"

def updateWaypoint(waypoint):
    """Interpretuje zawartości pól dla tablicy informacji o punktach nawigacyjnych

    Args:
        waypoint (waypoint): struktura danych dla tablicy informacji o punktach nawigacyjnych
    """
    to_update_index = waypoint.fields.index("\tLongitude")
    if waypoint.dataParts[to_update_index] == 181:
        waypoint.dataParts[to_update_index] = "N/A"
    elif waypoint.dataParts[to_update_index] > 0:
        waypoint.dataParts[to_update_index] = "{} minutes (E)".format(waypoint.dataParts[to_update_index])
    elif waypoint.dataParts[to_update_index] < 0:
        waypoint.dataParts[to_update_index] = "{} minutes (W)".format(waypoint.dataParts[to_update_index])

    to_update_index = waypoint.fields.index("\tLatitude")
    if waypoint.dataParts[to_update_index] == 91:
        waypoint.dataParts[to_update_index] = "N/A"
    elif waypoint.dataParts[to_update_index] > 0:
        waypoint.dataParts[to_update_index] = "{} minutes (N)".format(waypoint.dataParts[to_update_index])
    elif waypoint.dataParts[to_update_index] < 0:
        waypoint.dataParts[to_update_index] = "{} minutes (S)".format(waypoint.dataParts[to_update_index]) 

def updateImo289Tidal(tidal):
    """Interpretuje zawartości pól dla tablicy informacji o pływach

    Args:
        tidal (imo289_tidal): truktura danych dla tablicy informacji o pływach
    """
    to_update_index = tidal.fields.index("\tLongitude")
    if tidal.dataParts[to_update_index] == 181:
        tidal.dataParts[to_update_index] = "N/A"
    elif tidal.dataParts[to_update_index] > 0:
        tidal.dataParts[to_update_index] = "{} minutes (E)".format(tidal.dataParts[to_update_index])
    elif tidal.dataParts[to_update_index] < 0:
        tidal.dataParts[to_update_index] = "{} minutes (W)".format(tidal.dataParts[to_update_index])

    to_update_index = tidal.fields.index("\tLatitude")
    if tidal.dataParts[to_update_index] == 91:
        tidal.dataParts[to_update_index] = "N/A"
    elif tidal.dataParts[to_update_index] > 0:
        tidal.dataParts[to_update_index] = "{} minutes (N)".format(tidal.dataParts[to_update_index])
    elif tidal.dataParts[to_update_index] < 0:
        tidal.dataParts[to_update_index] = "{} minutes (S)".format(tidal.dataParts[to_update_index]) 

    to_update_index = tidal.fields.index("\tFrom UTC Hour")
    if(tidal.dataParts[to_update_index]) == 24:
        tidal.dataParts[to_update_index] = "N/A"
    to_update_index = tidal.fields.index("\tFrom UTC Minute")
    if(tidal.dataParts[to_update_index]) == 60:
        tidal.dataParts[to_update_index] = "N/A"
    to_update_index = tidal.fields.index("\tTo UTC Hour")
    if(tidal.dataParts[to_update_index]) == 24:
        tidal.dataParts[to_update_index] = "N/A"
    to_update_index = tidal.fields.index("\tTo UTC Minute")
    if(tidal.dataParts[to_update_index]) == 60:
        tidal.dataParts[to_update_index] = "N/A"

    to_update_index = tidal.fields.index("\tCurrent Direction Predicted")
    if tidal.dataParts[to_update_index] == 360:
        tidal.dataParts[to_update_index] = "N/A"
    else:
        tidal.dataParts[to_update_index] = "{} deg".format(tidal.dataParts[to_update_index])

    to_update_index = tidal.fields.index("\tCurrent Speed Predicted")
    if tidal.dataParts[to_update_index] == 12.7:
        tidal.dataParts[to_update_index] = "N/A"
    else:
        tidal.dataParts[to_update_index] = "{} knots".format(tidal.dataParts[to_update_index])

def updateDestinationMMSI(mmsi):
    """Interpretuje zawartości pól dla tablicy informacji o MMSI odbiorcy

    Args:
        mmsi (destinationMMSI): struktura danych dla tablicy informacji o MMSI odbiorcy
    """
    pass

def updateCircleOrPoint(cop):
    """Interpretuje zawartości pól dla tablicy informacji o kształcie obszaru - typ Circle or Point

    Args:
        cop (circle_or_point): struktura danych dla tablicy informacji o kształcie obszaru - typ Circle or Point
    """
    to_update_index = cop.fields.index("\tLongitude")
    if cop.dataParts[to_update_index] == 181:
        cop.dataParts[to_update_index] = "N/A"
    elif cop.dataParts[to_update_index] > 0:
        cop.dataParts[to_update_index] = "{} minutes (E)".format(cop.dataParts[to_update_index])
    elif cop.dataParts[to_update_index] < 0:
        cop.dataParts[to_update_index] = "{} minutes (W)".format(cop.dataParts[to_update_index])

    to_update_index = cop.fields.index("\tLatitude")
    if cop.dataParts[to_update_index] == 91:
        cop.dataParts[to_update_index] = "N/A"
    elif cop.dataParts[to_update_index] > 0:
        cop.dataParts[to_update_index] = "{} minutes (N)".format(cop.dataParts[to_update_index])
    elif cop.dataParts[to_update_index] < 0:
        cop.dataParts[to_update_index] = "{} minutes (S)".format(cop.dataParts[to_update_index]) 

    to_update_index = cop.fields.index("\tPrecision")
    cop.dataParts[to_update_index] = "{} decimal places".format(cop.target[to_update_index])

    to_update_index = cop.fields.index("\tRadius")
    if cop.dataParts[to_update_index] == 0:
        cop.dataParts[to_update_index] = "point"
    else:
        cop.dataParts[to_update_index] = "{}*10^scale metres".format(cop.dataParts[to_update_index])

def updateRectangle(rectangle):
    """Interpretuje zawartości pól dla tablicy informacji o kształcie obszaru - typ Rectangle

    Args:
        rectangle (rectangle): struktura danych dla tablicy informacji o kształcie obszaru - typ Rectangle
    """
    to_update_index = rectangle.fields.index("\tLongitude")
    if rectangle.dataParts[to_update_index] == 181:
        rectangle.dataParts[to_update_index] = "N/A"
    elif rectangle.dataParts[to_update_index] > 0:
        rectangle.dataParts[to_update_index] = "{} minutes (E)".format(rectangle.dataParts[to_update_index])
    elif rectangle.dataParts[to_update_index] < 0:
        rectangle.dataParts[to_update_index] = "{} minutes (W)".format(rectangle.dataParts[to_update_index])

    to_update_index = rectangle.fields.index("\tLatitude")
    if rectangle.dataParts[to_update_index] == 91:
        rectangle.dataParts[to_update_index] = "N/A"
    elif rectangle.dataParts[to_update_index] > 0:
        rectangle.dataParts[to_update_index] = "{} minutes (N)".format(rectangle.dataParts[to_update_index])
    elif rectangle.dataParts[to_update_index] < 0:
        rectangle.dataParts[to_update_index] = "{} minutes (S)".format(rectangle.dataParts[to_update_index]) 

    to_update_index = rectangle.fields.index("\tPrecision")
    rectangle.dataParts[to_update_index] = "{} decimal places".format(rectangle.target[to_update_index])

    to_update_index = rectangle.fields.index("\tE dimension")
    if rectangle.dataParts[to_update_index] == 0:
        rectangle.dataParts[to_update_index] = "N/S line"
    else:
        rectangle.dataParts[to_update_index] = "{}^scale metres".format(rectangle.dataParts[to_update_index])
    to_update_index = rectangle.fields.index("\tN dimension")
    if rectangle.dataParts[to_update_index] == 0:
        rectangle.dataParts[to_update_index] = "W/E line"
    else:
        rectangle.dataParts[to_update_index] = "{}*10^scale metres".format(rectangle.dataParts[to_update_index])

    to_update_index = rectangle.fields.index("\tOrientation")
    if rectangle.dataParts[to_update_index] == 0:
        rectangle.dataParts[to_update_index] = "No rotation"
    else:
        rectangle.dataParts[to_update_index] = "{} degrees clockwise from true north".format(rectangle.dataParts[to_update_index])

def updateSector(sector):
    """Interpretuje zawartości pól dla tablicy informacji o kształcie obszaru - typ Sector

    Args:
        sector (sector): struktura danych dla tablicy informacji o kształcie obszaru - typ Sector
    """
    to_update_index = sector.fields.index("\tLongitude")
    if sector.dataParts[to_update_index] == 181:
        sector.dataParts[to_update_index] = "N/A"
    elif sector.dataParts[to_update_index] > 0:
        sector.dataParts[to_update_index] = "{} minutes (E)".format(sector.dataParts[to_update_index])
    elif sector.dataParts[to_update_index] < 0:
        sector.dataParts[to_update_index] = "{} minutes (W)".format(sector.dataParts[to_update_index])

    to_update_index = sector.fields.index("\tLatitude")
    if sector.dataParts[to_update_index] == 91:
        sector.dataParts[to_update_index] = "N/A"
    elif sector.dataParts[to_update_index] > 0:
        sector.dataParts[to_update_index] = "{} minutes (N)".format(sector.dataParts[to_update_index])
    elif sector.dataParts[to_update_index] < 0:
        sector.dataParts[to_update_index] = "{} minutes (S)".format(sector.dataParts[to_update_index]) 

    to_update_index = sector.fields.index("\tPrecision")
    sector.dataParts[to_update_index] = "{} decimal places".format(sector.target[to_update_index])

    to_update_index = sector.fields.index("\tRadius")
    if sector.dataParts[to_update_index] == 0:
        sector.dataParts[to_update_index] = "point"
    else:
        sector.dataParts[to_update_index] = "{}^scale metres".format(sector.dataParts[to_update_index])

    to_update_index = sector.fields.index("\tLeft boundary")
    if sector.dataParts[to_update_index] == 0:
        sector.dataParts[to_update_index] = "No rotation"
    else:
        sector.dataParts[to_update_index] = "{}^ degrees clockwise from true north".format(sector.dataParts[to_update_index])
    to_update_index = sector.fields.index("\tRight boundary")
    if sector.dataParts[to_update_index] == 0:
        sector.dataParts[to_update_index] = "No rotation"
    else:
        sector.dataParts[to_update_index] = "{}^ degrees clockwise from true north".format(sector.dataParts[to_update_index])

def updatePolyline(polyline):
    """Interpretuje zawartości pól dla tablicy informacji o kształcie obszaru - typ Polyline

    Args:
        polyline (polyline): struktura danych dla tablicy informacji o kształcie obszaru - typ Polyline
    """
    updaters.concatenateFields(polyline.waypoints, polyline.fields)
    updaters.concatenateDataparts(polyline.waypoints, polyline.dataParts)

def updatePolylineWaypoint(waypoint):
    """Interpretuje zawartości pól dla tablicy punktów kształtu obszaru o typie Polyline

    Args:
        waypoint (polyline_waypoint): struktura danych dla tablicy punktów kształtu obszaru o typie Polyline
    """
    to_update_index = waypoint.fields.index("\t\tBearing")
    if waypoint.dataParts[to_update_index] == 720:
        waypoint.dataPartss[to_update_index] = "N/A"
    else:
        waypoint.dataParts[to_update_index] = "{} (True bearing in half-degree steps from previous waypoint)".format(waypoint.dataParts[to_update_index])

    to_update_index = waypoint.fields.index("\t\tDistance")
    if waypoint.dataParts[to_update_index] == 0:
        waypoint.dataPartss[to_update_index] = "No point"
    else:
        waypoint.dataParts[to_update_index] = "{}*10^scale metres (from prev. waypoint)".format(waypoint.dataParts[to_update_index])

def updatePolygon(polygon):
    """Interpretuje zawartości pól dla tablicy informacji o kształcie obszaru - typ Polygon

    Args:
        polygon (polygon): struktura danych dla tablicy informacji o kształcie obszaru - typ Polygon
    """
    updaters.concatenateFields(polygon.vertices, polygon.fields)
    updaters.concatenateDataparts(polygon.vertices, polygon.dataParts)

def updatePolygonVertices(vertex):
    """Interpretuje zawartości pól dla tablicy wierzchołków kształtu obszaru o typie Polygon

    Args:
        vertex (polygon_vertices): struktura danych dla tablicy wierzchołków kształtu obszaru o typie Polygon
    """
    to_update_index = vertex.fields.index("\t\tBearing")
    if vertex.dataParts[to_update_index] == 720:
        vertex.dataPartss[to_update_index] = "N/A"
    else:
        vertex.dataParts[to_update_index] = "{} (True bearing in half-degree steps from previous vertex)".format(vertex.dataParts[to_update_index])

    to_update_index = vertex.fields.index("\t\tDistance")
    if vertex.dataParts[to_update_index] == 0:
        vertex.dataPartss[to_update_index] = "No point"
    else:
        vertex.dataParts[to_update_index] = "{}*10^scale metres (from prev. vertex)".format(vertex.dataParts[to_update_index])    

def updateAssociatedText(text):
    """Interpretuje zawartości pól dla tablicy informacji o kształcie obszaru - typ Associated Text

    Args:
        text (associated_text): struktura danych dla tablicy informacji o kształcie obszaru - typ Associated Text
    """
    pass

def updateTarget(target):
    """Interpretuje zawartości pól dla tablicy informacji o celu

    Args:
        target (target): struktura danych dla tablicy informacji o celu
    """
    to_update_index = target.fields.index("\tIdentifier type")
    idtypes = ["MMSI number", "IMO number", "call sign", "other"]
    target.dataParts[to_update_index] = idtypes[target.dataParts[to_update_index]]

    to_update_index = target.fields.index("\tLatitude")
    if target.dataParts[to_update_index] == 91:
        target.dataParts[to_update_index] = "N/A"
    elif target.dataParts[to_update_index] > 0:
        target.dataParts[to_update_index] = "{} minutes (N)".format(target.dataParts[to_update_index])
    elif target.dataParts[to_update_index] < 0:
        target.dataParts[to_update_index] = "{} minutes (S)".format(target.dataParts[to_update_index]) 

    to_update_index = target.fields.index("\tLongitude")
    if target.dataParts[to_update_index] == 181:
        target.dataParts[to_update_index] = "N/A"
    elif target.dataParts[to_update_index] > 0:
        target.dataParts[to_update_index] = "{} minutes (E)".format(target.dataParts[to_update_index])
    elif target.dataParts[to_update_index] < 0:
        target.dataParts[to_update_index] = "{} minutes (W)".format(target.dataParts[to_update_index])

    to_update_index = target.fields.index("\tCourse Over Ground")
    if target.dataParts[to_update_index] == 360:
        target.dataParts[to_update_index] = "N/A"
    else:
        target.dataParts[to_update_index] = "{} deg from true north".format(target.dataParts[to_update_index])

    to_update_index = target.fields.index("\tTime Stamp")
    if target.dataParts[to_update_index] == 60:
        target.dataParts[to_update_index] = "not available"
    elif target.dataParts[to_update_index] == 61:
        target.dataParts[to_update_index] = "positioning system in manual input mode"
    elif target.dataParts[to_update_index] == 62:
        target.dataParts[to_update_index] == "Electronic Position Fixing System operates in estimated (dead reckoning) mode"
    elif target.dataParts[to_update_index] == 63:
        target.dataParts[to_update_index] == "positioning system is inoperative"
    else:
        target.dataParts[to_update_index] = str(target.dataParts[to_update_index]) + "second of UTC timestamp"

    to_update_index = target.fields.index("\tSpeed Over Ground")
    if target.dataParts[to_update_index] == 255:
        target.dataParts[to_update_index] = "N/A"
    else:
        target.dataParts[to_update_index] = "{} knots".format(target.dataParts[to_update_index])

def updateReport(report):
    """Interpretuje zawartości pól dla tablicy informacji o typach odczytu czujnika

    Args:
        report (report): struktura danych dla tablicy informacji o typach odczytu czujnika
    """
    to_update_index = report.fields.index("\tDay (UTC)")
    if(report.dataParts[to_update_index]) == 0:
        report.dataParts[to_update_index] = "N/A"
    to_update_index = report.fields.index("\tHour (UTC)")
    if(report.dataParts[to_update_index]) == 24:
        report.dataParts[to_update_index] = "N/A (UTC)"
    to_update_index = report.fields.index("\tMinute (UTC)")
    if(report.dataParts[to_update_index]) == 60:
        report.dataParts[to_update_index] = "N/A"

def updateSiteLocationPayload(sloc):
    """Interpretuje zawartości pól dla tablicy informacji o odczycie czujnika - typ Site Location

    Args:
        sloc (siteLocationPayload): struktura danych dla tablicy informacji o odczycie czujnika - typ Site Location
    """
    to_update_index = sloc.fields.index("\t\tLongitude")
    sloc.dataParts[to_update_index] = updaters.calculateLongitude(sloc.dataParts[to_update_index])
    to_update_index = sloc.fields.index("\t\tLatitude")
    sloc.dataParts[to_update_index] = updaters.calculateLatitude(sloc.dataParts[to_update_index])

    to_update_index = sloc.fields.index("\t\tAltitude")
    if sloc.dataParts[to_update_index] == 2001:
        sloc.dataParts[to_update_index] = "200.1 m or higher"
    elif sloc.dataParts[to_update_index] == 2002:
        sloc.dataParts[to_update_index] = "N/A"
    else:
        sloc.dataParts[to_update_index] = "{} m above MSL".format(sloc.dataParts[to_update_index])

    to_update_index = sloc.fields.index("\t\tSensor owner")
    sloc.dataParts[to_update_index] = enums.sensorOwnerCodes[sloc.dataParts[to_update_index]]

    to_update_index = sloc.fields.index("\t\tData timeout")
    sloc.dataParts[to_update_index] = enums.dataTimeoutCodes[sloc.dataParts[to_update_index]]

def updateStationIdPayload(sid):
    """Interpretuje zawartości pól dla tablicy informacji o odczycie czujnika - typ Station ID

    Args:
        sid (stationIdPayload): struktura danych dla tablicy informacji o odczycie czujnika - typ Station ID
    """
    pass

def updateWindPayload(wind):
    """Interpretuje zawartości pól dla tablicy informacji o odczycie czujnika - typ Wind

    Args:
        wind (windPayload): struktura danych dla tablicy informacji o odczycie czujnika - typ Wind
    """
    to_update_index = wind.fields.index("\t\tAverage Wind Speed")
    if(wind.dataParts[to_update_index] == 122):
        wind.dataParts[to_update_index] = "N/A"
    elif wind.dataParts[to_update_index] == 121:
        wind.dataParts[to_update_index] = "121 knots or more"
    else:
        wind.dataParts[to_update_index] = "{} knots (10-min avg)".format(wind.dataParts[to_update_index])    

    to_update_index = wind.fields.index("\t\tWind Gust")
    if(wind.dataParts[to_update_index] == 122):
        wind.dataParts[to_update_index] = "N/A"
    elif wind.dataParts[to_update_index] == 121:
        wind.dataParts[to_update_index] = "121 knots or more"
    else:
        wind.dataParts[to_update_index] = "{} knots (10-min avg)".format(wind.dataParts[to_update_index])   

    to_update_index = wind.fields.index("\t\tWind Direction")
    if wind.dataParts[to_update_index] >= 360:
        wind.dataParts[to_update_index] = "N/A"
    else:
        wind.dataParts[to_update_index] = "{} degrees from true north".format(wind.dataParts[to_update_index])

    to_update_index = wind.fields.index("\t\tWind Gust Direction")
    if wind.dataParts[to_update_index] >= 360:
        wind.dataParts[to_update_index] = "N/A"
    else:
        wind.dataParts[to_update_index] = "{} degrees from true north".format(wind.dataParts[to_update_index])

    to_update_index = wind.fields.index("\t\tSensor Description")
    wind.dataParts[to_update_index] = enums.sensorTypes[wind.dataParts[to_update_index]]

    to_update_index = wind.fields.index("\t\tForecast Wind Speed")
    if(wind.dataParts[to_update_index] == 122):
        wind.dataParts[to_update_index] = "N/A"
    elif wind.dataParts[to_update_index] == 121:
        wind.dataParts[to_update_index] = "121 knots or more"
    else:
        wind.dataParts[to_update_index] = "{} knots".format(wind.dataParts[to_update_index])  

    to_update_index = wind.fields.index("\t\tForecast Wind Gust")
    if(wind.dataParts[to_update_index] == 122):
        wind.dataParts[to_update_index] = "N/A"
    elif wind.dataParts[to_update_index] == 121:
        wind.dataParts[to_update_index] = "121 knots or more"
    else:
        wind.dataParts[to_update_index] = "{} knots".format(wind.dataParts[to_update_index])  

    to_update_index = wind.fields.index("\t\tForecast Wind Direction")
    if wind.dataParts[to_update_index] >= 360:
        wind.dataParts[to_update_index] = "N/A"
    else:
        wind.dataParts[to_update_index] = "{} degrees from true north".format(wind.dataParts[to_update_index])

    to_update_index = wind.fields.index("\t\tDay (UTC)")
    if(wind.dataParts[to_update_index]) == 0:
        wind.dataParts[to_update_index] = "N/A"
    to_update_index = wind.fields.index("\t\tHour (UTC)")
    if(wind.dataParts[to_update_index]) == 24:
        wind.dataParts[to_update_index] = "N/A (UTC)"
    to_update_index = wind.fields.index("\t\tMinute (UTC)")
    if(wind.dataParts[to_update_index]) == 60:
        wind.dataParts[to_update_index] = "N/A"

    to_update_index = wind.fields.index("\t\tForecast Duration")
    if wind.dataParts[to_update_index] == 0:
        wind.dataParts[to_update_index] = "cancel forecast"
    elif wind.dataParts[to_update_index] == 255:
        wind.dataParts[to_update_index] = "N/A"
    else:
        wind.dataParts[to_update_index] = "{} minutes".format(wind.dataParts[to_update_index])

def updateWaterLevelPayload(water):
    """Interpretuje zawartości pól dla tablicy informacji o odczycie czujnika - typ Water Level

    Args:
        water (waterLevelPayload): struktura danych dla tablicy informacji o odczycie czujnika - typ Water Level
    """
    to_update_index = water.fields.index("\t\tWater Level Type")
    level_types = ["relative to reference datum", "not relative to reference datum"]
    water.dataParts[to_update_index] = level_types[water.dataParts[to_update_index]]

    to_update_index = water.fields.index("\t\tWater Level")
    if water.dataParts[to_update_index] == -32767:
        water.dataParts[to_update_index] = "-327.67 metres or less"
    elif water.dataParts[to_update_index] == 32767:
        water.dataParts[to_update_index] = "327.67 metres or more"
    elif water.dataParts[to_update_index] == -32768:
        water.dataParts[to_update_index] = "N/A"
    else:
        water.dataParts[to_update_index] = "{} meter steps".format(water.dataParts[to_update_index]*0.01)

    to_update_index = water.fields.index("\t\tWater Level Trend")
    wtrends = ["increasing", "decreasing", "steady", "N/A"]
    water.dataParts[to_update_index] = wtrends[water.dataParts[to_update_index]]

    to_update_index = water.fields.index("\t\tVertical Reference Datum")
    water.dataParts[to_update_index] = enums.verticalReferenceDatum[water.dataParts[to_update_index]]

    to_update_index = water.fields.index("\t\tSensor Description")
    water.dataParts[to_update_index] = enums.sensorTypes[water.dataParts[to_update_index]]

    to_update_index = water.fields.index("\t\tForecast Water Level Type")
    level_types = ["relative to reference datum", "not relative to reference datum"]
    water.dataParts[to_update_index] = level_types[water.dataParts[to_update_index]]

    to_update_index = water.fields.index("\t\tForecast Water Level")
    if water.dataParts[to_update_index] == -32767:
        water.dataParts[to_update_index] = "-327.67 metres or less"
    elif water.dataParts[to_update_index] == 32767:
        water.dataParts[to_update_index] = "327.67 metres or more"
    elif water.dataParts[to_update_index] == -32768:
        water.dataParts[to_update_index] = "N/A"
    else:
        water.dataParts[to_update_index] = "{} meter steps".format(water.dataParts[to_update_index]*0.01)   

    to_update_index = water.fields.index("\t\tDay (UTC)")
    if(water.dataParts[to_update_index]) == 0:
        water.dataParts[to_update_index] = "N/A"
    to_update_index = water.fields.index("\t\tHour (UTC)")
    if(water.dataParts[to_update_index]) == 24:
        water.dataParts[to_update_index] = "N/A (UTC)"
    to_update_index = water.fields.index("\t\tMinute (UTC)")
    if(water.dataParts[to_update_index]) == 60:
        water.dataParts[to_update_index] = "N/A"

    to_update_index = water.fields.index("\t\tForecast Duration")
    if water.dataParts[to_update_index] == 0:
        water.dataParts[to_update_index] = "cancel forecast"
    elif water.dataParts[to_update_index] == 255:
        water.dataParts[to_update_index] = "N/A"
    else:
        water.dataParts[to_update_index] = "{} minutes".format(water.dataParts[to_update_index]) 

def updateCurrentFlow2dPayload(current):
    """Interpretuje zawartości pól dla tablicy informacji o odczycie czujnika - typ Current Flow (2D)

    Args:
        current (currentFlow2d): struktura danych dla tablicy informacji o odczycie czujnika - typ Current Flow (2D)
    """
    to_update_index = current.fields.index("\t\tCurrent Speed 1")
    if current.dataParts[to_update_index] == 24.6:
        current.dataParts[to_update_index] = "24.6 knots or more"
    elif current.dataParts[to_update_index] == 24.7:
        current.dataParts[to_update_index] = "N/A"
    else:
        current.dataParts[to_update_index] = "{} knots".format(current.dataParts[to_update_index])

    to_update_index = current.fields.index("\t\tCurrent Direction 1")
    if current.dataParts[to_update_index] == 360:
        current.dataParts[to_update_index] = "N/A"
    else:
        current.dataParts[to_update_index] = "{} deg from true north".format(current.dataParts[to_update_index])

    to_update_index = current.fields.index("\t\tMeasurement Depth 1")
    if current.dataParts[to_update_index] == 361:
        current.dataParts[to_update_index] = "361 metres or greater"
    elif current.dataParts[to_update_index] == 362:
        current.dataParts[to_update_index] = "N/A"
    else:
        current.dataParts[to_update_index] = "{} metres down".format(current.dataParts[to_update_index])

    to_update_index = current.fields.index("\t\tCurrent Speed 2")
    if current.dataParts[to_update_index] == 24.6:
        current.dataParts[to_update_index] = "24.6 knots or more"
    elif current.dataParts[to_update_index] == 24.7:
        current.dataParts[to_update_index] = "N/A"
    else:
        current.dataParts[to_update_index] = "{} knots".format(current.dataParts[to_update_index])

    to_update_index = current.fields.index("\t\tCurrent Direction 2")
    if current.dataParts[to_update_index] == 360:
        current.dataParts[to_update_index] = "N/A"
    else:
        current.dataParts[to_update_index] = "{} deg from true north".format(current.dataParts[to_update_index])

    to_update_index = current.fields.index("\t\tMeasurement Depth 2")
    if current.dataParts[to_update_index] == 361:
        current.dataParts[to_update_index] = "361 metres or greater"
    elif current.dataParts[to_update_index] == 362:
        current.dataParts[to_update_index] = "N/A"
    else:
        current.dataParts[to_update_index] = "{} metres down".format(current.dataParts[to_update_index])

    to_update_index = current.fields.index("\t\tCurrent Speed 3")
    if current.dataParts[to_update_index] == 24.6:
        current.dataParts[to_update_index] = "24.6 knots or more"
    elif current.dataParts[to_update_index] == 24.7:
        current.dataParts[to_update_index] = "N/A"
    else:
        current.dataParts[to_update_index] = "{} knots".format(current.dataParts[to_update_index])

    to_update_index = current.fields.index("\t\tCurrent Direction 3")
    if current.dataParts[to_update_index] == 360:
        current.dataParts[to_update_index] = "N/A"
    else:
        current.dataParts[to_update_index] = "{} deg from true north".format(current.dataParts[to_update_index])

    to_update_index = current.fields.index("\t\tMeasurement Depth 3")
    if current.dataParts[to_update_index] == 361:
        current.dataParts[to_update_index] = "361 metres or greater"
    elif current.dataParts[to_update_index] == 362:
        current.dataParts[to_update_index] = "N/A"
    else:
        current.dataParts[to_update_index] = "{} metres down".format(current.dataParts[to_update_index])

    to_update_index = current.fields.index("\t\tSensor Description")
    current.dataParts[to_update_index] = enums.sensorTypes[current.dataParts[to_update_index]]

def updateCurrentFlow3dPayload(current):
    """Interpretuje zawartości pól dla tablicy informacji o odczycie czujnika - typ Current Flow (3D)

    Args:
        current (currentFlow3d): struktura danych dla tablicy informacji o odczycie czujnika - typ Current Flow (3D)
    """
    to_update_index = current.fields.index("\t\tCurrent Vector component North (u) 1")
    if current.dataParts[to_update_index] == 24.6:
        current.dataParts[to_update_index] = "24.6 knots or more"
    elif current.dataParts[to_update_index] == 24.7:
        current.dataParts[to_update_index] = "N/A"
    else:
        current.dataParts[to_update_index] = "{} knots".format(current.dataParts[to_update_index])

    to_update_index = current.fields.index("\t\tCurrent Vector component North (v) 1")
    if current.dataParts[to_update_index] == 24.6:
        current.dataParts[to_update_index] = "24.6 knots or more"
    elif current.dataParts[to_update_index] == 24.7:
        current.dataParts[to_update_index] = "N/A"
    else:
        current.dataParts[to_update_index] = "{} knots".format(current.dataParts[to_update_index])

    to_update_index = current.fields.index("\t\tCurrent Vector component North (z) 1")
    if current.dataParts[to_update_index] == 24.6:
        current.dataParts[to_update_index] = "24.6 knots or more"
    elif current.dataParts[to_update_index] == 24.7:
        current.dataParts[to_update_index] = "N/A"
    else:
        current.dataParts[to_update_index] = "{} knots".format(current.dataParts[to_update_index])

    to_update_index = current.fields.index("\t\tMeasurement Depth 1")
    if current.dataParts[to_update_index] == 361:
        current.dataParts[to_update_index] = "361 metres or greater"
    elif current.dataParts[to_update_index] == 362:
        current.dataParts[to_update_index] = "N/A"
    else:
        current.dataParts[to_update_index] = "{} metres down".format(current.dataParts[to_update_index])

    to_update_index = current.fields.index("\t\tCurrent Vector component North (u) 2")
    if current.dataParts[to_update_index] == 24.6:
        current.dataParts[to_update_index] = "24.6 knots or more"
    elif current.dataParts[to_update_index] == 24.7:
        current.dataParts[to_update_index] = "N/A"
    else:
        current.dataParts[to_update_index] = "{} knots".format(current.dataParts[to_update_index])

    to_update_index = current.fields.index("\t\tCurrent Vector component North (v) 2")
    if current.dataParts[to_update_index] == 24.6:
        current.dataParts[to_update_index] = "24.6 knots or more"
    elif current.dataParts[to_update_index] == 24.7:
        current.dataParts[to_update_index] = "N/A"
    else:
        current.dataParts[to_update_index] = "{} knots".format(current.dataParts[to_update_index])

    to_update_index = current.fields.index("\t\tCurrent Vector component North (z) 2")
    if current.dataParts[to_update_index] == 24.6:
        current.dataParts[to_update_index] = "24.6 knots or more"
    elif current.dataParts[to_update_index] == 24.7:
        current.dataParts[to_update_index] = "N/A"
    else:
        current.dataParts[to_update_index] = "{} knots".format(current.dataParts[to_update_index])

    to_update_index = current.fields.index("\t\tMeasurement Depth 2")
    if current.dataParts[to_update_index] == 361:
        current.dataParts[to_update_index] = "361 metres or greater"
    elif current.dataParts[to_update_index] == 362:
        current.dataParts[to_update_index] = "N/A"
    else:
        current.dataParts[to_update_index] = "{} metres down".format(current.dataParts[to_update_index])

    to_update_index = current.fields.index("\t\tSensor Description")
    current.dataParts[to_update_index] = enums.sensorTypes[current.dataParts[to_update_index]]

def updateHorizontalCurrentFlowPayload(current):
    """Interpretuje zawartości pól dla tablicy informacji o odczycie czujnika - typ Horizontal Current Flow

    Args:
        current (horizontalCurrentFlow): struktura danych dla tablicy informacji o odczycie czujnika - typ Horizontal Current Flow
    """
    to_update_index = current.fields.index("\t\tCurrent Bearing 1")
    if current.dataParts[to_update_index] == 360:
        current.dataParts[to_update_index] = "N/A"
    else:
        current.dataParts[to_update_index] = "{} deg from true north".format(current.dataParts[to_update_index])

    to_update_index = current.fields.index("\t\tCurrent Distance 1")
    if current.dataParts[to_update_index] == 121:
        current.dataParts[to_update_index] = "121 metres or greater"
    elif current.dataParts[to_update_index] == 122:
        current.dataParts[to_update_index] = "N/A"
    else:
        current.dataParts[to_update_index] = "{} metres".format(current.dataParts[to_update_index])

    to_update_index = current.fields.index("\t\tCurrent Speed 1")
    if current.dataParts[to_update_index] == 24.6:
        current.dataParts[to_update_index] = "24.6 knots or more"
    elif current.dataParts[to_update_index] == 24.7:
        current.dataParts[to_update_index] = "N/A"
    else:
        current.dataParts[to_update_index] = "{} knots".format(current.dataParts[to_update_index])

    to_update_index = current.fields.index("\t\tCurrent Direction 1")
    if current.dataParts[to_update_index] == 360:
        current.dataParts[to_update_index] = "N/A"
    else:
        current.dataParts[to_update_index] = "{} deg from true north".format(current.dataParts[to_update_index])

    to_update_index = current.fields.index("\t\tMeasurement Depth 1")
    if current.dataParts[to_update_index] == 361:
        current.dataParts[to_update_index] = "361 metres or greater"
    elif current.dataParts[to_update_index] == 362:
        current.dataParts[to_update_index] = "N/A"
    else:
        current.dataParts[to_update_index] = "{} metres down".format(current.dataParts[to_update_index])

    to_update_index = current.fields.index("\t\tCurrent Bearing 2")
    if current.dataParts[to_update_index] == 360:
        current.dataParts[to_update_index] = "N/A"
    else:
        current.dataParts[to_update_index] = "{} deg from true north".format(current.dataParts[to_update_index])

    to_update_index = current.fields.index("\t\tCurrent Distance 2")
    if current.dataParts[to_update_index] == 121:
        current.dataParts[to_update_index] = "121 metres or greater"
    elif current.dataParts[to_update_index] == 122:
        current.dataParts[to_update_index] = "N/A"
    else:
        current.dataParts[to_update_index] = "{} metres".format(current.dataParts[to_update_index])

    to_update_index = current.fields.index("\t\tCurrent Speed 2")
    if current.dataParts[to_update_index] == 24.6:
        current.dataParts[to_update_index] = "24.6 knots or more"
    elif current.dataParts[to_update_index] == 24.7:
        current.dataParts[to_update_index] = "N/A"
    else:
        current.dataParts[to_update_index] = "{} knots".format(current.dataParts[to_update_index])

    to_update_index = current.fields.index("\t\tCurrent Direction 2")
    if current.dataParts[to_update_index] == 360:
        current.dataParts[to_update_index] = "N/A"
    else:
        current.dataParts[to_update_index] = "{} deg from true north".format(current.dataParts[to_update_index])

    to_update_index = current.fields.index("\t\tMeasurement Depth 2")
    if current.dataParts[to_update_index] == 361:
        current.dataParts[to_update_index] = "361 metres or greater"
    elif current.dataParts[to_update_index] == 362:
        current.dataParts[to_update_index] = "N/A"
    else:
        current.dataParts[to_update_index] = "{} metres down".format(current.dataParts[to_update_index])

def updateSeaStatePayload(sea):
    """Interpretuje zawartości pól dla tablicy informacji o odczycie czujnika - typ Sea State

    Args:
        sea (seaStatePayload): struktura danych dla tablicy informacji o odczycie czujnika - typ Sea State
    """
    to_update_index = sea.fields.index("\t\tSwell Height")
    if sea.dataParts[to_update_index] == 24.6:
        sea.dataParts[to_update_index] = "24.6 metres or more"
    elif sea.dataParts[to_update_index] == 24.7:
        sea.dataParts[to_update_index] = "N/A"
    else:
        sea.dataParts[to_update_index] = "{} metres".format(sea.dataParts[to_update_index])

    to_update_index = sea.fields.index("\t\tSwell Period")
    if sea.dataParts[to_update_index] == 61:
        sea.dataParts[to_update_index] = "N/A"
    else:
        sea.dataParts[to_update_index] = "{} seconds".format(sea.dataParts[to_update_index])

    to_update_index = sea.fields.index("\t\tSwell Direction")
    if sea.dataParts[to_update_index] == 360:
        sea.dataParts[to_update_index] = "N/A"
    else:
        sea.dataParts[to_update_index] = "{} deg from true north".format(sea.dataParts[to_update_index])

    to_update_index = sea.fields.index("\t\tSea State")
    if sea.dataParts[to_update_index] == 13:
        sea.dataParts[to_update_index] = "N/A"
    else:
        sea.dataParts[to_update_index] = "{} (Beaufort scale)".format(sea.dataParts[to_update_index])

    to_update_index = sea.fields.index("\t\tSwell Sensor Description")
    sea.dataParts[to_update_index] = enums.sensorTypes[sea.dataParts[to_update_index]]

    to_update_index = sea.fields.index("\t\tWater Temperature")
    if sea.dataParts[to_update_index] == 60.1:
        sea.dataParts[to_update_index] = "N/A"
    else:
        sea.dataParts[to_update_index] = "{} deg C".format(sea.dataParts[to_update_index] - 10)

    to_update_index = sea.fields.index("\t\tWater Temperature Depth")
    if sea.dataParts[to_update_index] == 12.1:
        sea.dataParts[to_update_index] = "12.1 metres or greater"
    elif sea.dataParts[to_update_index] == 12.2:
        sea.dataParts[to_update_index] = "N/A"
    else:
        sea.dataParts[to_update_index] = "{} metres".format(sea.dataParts[to_update_index])
    
    to_update_index = sea.fields.index("\t\tDepth Sensor Description")
    sea.dataParts[to_update_index] = enums.sensorTypes[sea.dataParts[to_update_index]]

    to_update_index = sea.fields.index("\t\tWave Height")
    if sea.dataParts[to_update_index] == 24.6:
        sea.dataParts[to_update_index] = "24.6 metres or more"
    elif sea.dataParts[to_update_index] == 24.7:
        sea.dataParts[to_update_index] = "N/A"
    else:
        sea.dataParts[to_update_index] = "{} metres".format(sea.dataParts[to_update_index])

    to_update_index = sea.fields.index("\t\tWave Period")
    if sea.dataParts[to_update_index] == 61:
        sea.dataParts[to_update_index] = "N/A"
    else:
        sea.dataParts[to_update_index] = "{} seconds".format(sea.dataParts[to_update_index])

    to_update_index = sea.fields.index("\t\tWave Direction")
    if sea.dataParts[to_update_index] == 360:
        sea.dataParts[to_update_index] = "N/A"
    else:
        sea.dataParts[to_update_index] = "{} deg from true north".format(sea.dataParts[to_update_index])

    to_update_index = sea.fields.index("\t\tWave Sensor Description")
    sea.dataParts[to_update_index] = enums.sensorTypes[sea.dataParts[to_update_index]]

    to_update_index = sea.fields.index("\t\tSalinity")
    if sea.dataParts[to_update_index] == 50.1:
        sea.dataParts[to_update_index] = "50.1 percent or more"
    elif sea.dataParts[to_update_index] == 50.2:
        sea.dataParts[to_update_index] = "data N/A"
    elif sea.dataParts[to_update_index] == 50.3:
        sea.dataParts[to_update_index] == "sensor N/A"
    else:
        sea.dataParts[to_update_index] = "{}%".format(sea.dataParts[to_update_index])

def updateSalinityPayload(salinity):
    """Interpretuje zawartości pól dla tablicy informacji o odczycie czujnika - typ Salinity

    Args:
        salinity (salinityPayload): struktura danych dla tablicy informacji o odczycie czujnika - typ Salinity
    """
    to_update_index = salinity.fields.index("\t\tWater Temperature")
    if salinity.dataParts[to_update_index] == 60.1:
        salinity.dataParts[to_update_index] = "N/A"
    else:
        salinity.dataParts[to_update_index] = "{} deg C".format(salinity.dataParts[to_update_index] - 10)

    to_update_index = salinity.fields.index("\t\tConductivity")
    if salinity.dataParts[to_update_index] == 70.1:
        salinity.dataParts[to_update_index] = "7.01 Siemens/m or more"
    elif salinity.dataParts[to_update_index] == 70.2:
        salinity.dataParts[to_update_index] = "data N/A"
    elif salinity.dataParts[to_update_index] == 70.3:
        salinity.dataParts[to_update_index] == "sensor N/A"
    else:
        salinity.dataParts[to_update_index] = "{} Siemens/m".format(salinity.dataParts[to_update_index])

    to_update_index = salinity.fields.index("\t\tWater Pressure")
    if salinity.dataParts[to_update_index] == 6000.1:
        salinity.dataParts[to_update_index] = "6000.1 decibars or more"
    elif salinity.dataParts[to_update_index] == 6000.2:
        salinity.dataParts[to_update_index] = "data N/A"
    elif salinity.dataParts[to_update_index] == 6000.3:
        salinity.dataParts[to_update_index] == "sensor N/A"
    else:
        salinity.dataParts[to_update_index] = "{} decibars".format(salinity.dataParts[to_update_index])

    to_update_index = salinity.fields.index("\t\tSalinity")
    if salinity.dataParts[to_update_index] == 50.1:
        salinity.dataParts[to_update_index] = "50.1 percent or more"
    elif salinity.dataParts[to_update_index] == 50.2:
        salinity.dataParts[to_update_index] = "data N/A"
    elif salinity.dataParts[to_update_index] == 50.3:
        salinity.dataParts[to_update_index] == "sensor N/A"
    else:
        salinity.dataParts[to_update_index] = "{}%".format(salinity.dataParts[to_update_index])

    to_update_index = salinity.fields.index("\t\tSalinity Type")
    types = ["measured", "calculated using PSS-78", "calculated using other method", "reserved"]
    salinity.dataParts[to_update_index] = types[salinity.dataParts[to_update_index]]

    to_update_index = salinity.fields.index("\t\tSensor Description")
    salinity.dataParts[to_update_index] = enums.sensorTypes[salinity.dataParts[to_update_index]]

def updateWeatherPayload(weather):
    """Interpretuje zawartości pól dla tablicy informacji o odczycie czujnika - typ Weather

    Args:
        weather (weatherPayload): struktura danych dla tablicy informacji o odczycie czujnika - typ Weather
    """
    to_update_index = weather.fields.index("\t\Air Temperature")
    if weather.dataParts[to_update_index] == -1024:
        weather.dataParts[to_update_index] = "N/A"
    else:
        weather.dataParts[to_update_index] = "{} deg C".format(weather.dataParts[to_update_index]*0.1)

    to_update_index = weather.fields.index("\t\tTemperature Sensor Type")
    weather.dataParts[to_update_index] = enums.sensorTypes[weather.dataParts[to_update_index]]

    to_update_index = weather.fields.index("\t\tPrecipitation Type")
    ptypes = ["rain", "rain and snow", "rain and snow", "other"]
    weather.dataParts[to_update_index] = ptypes[weather.dataParts[to_update_index]]

    to_update_index = weather.fields.index("\t\tHorizontal Visibility")
    if weather.dataParts[to_update_index] == 24.1:
        weather.dataParts[to_update_index] = "24.1 nautical miles or more"
    elif weather.dataParts[to_update_index] == 23.2:
        weather.dataParts[to_update_index] = "data N/A"
    elif weather.dataParts[to_update_index] == 24.3:
        weather.dataParts[to_update_index] == "sensor N/A"
    else:
        weather.dataParts[to_update_index] = "{} nautical miles".format(weather.dataParts[to_update_index])

    to_update_index = weather.fields.index("\t\tDew Point")
    if weather.dataParts[to_update_index] == 501:
        weather.dataParts[to_update_index] = "N/A"
    else:
        weather.dataParts[to_update_index] = "{} deg C".format(weather.dataParts[to_update_index]*0.1)

    to_update_index = weather.fields.index("\t\tDewpoint Sensor Type")
    weather.dataParts[to_update_index] = enums.sensorTypes[weather.dataParts[to_update_index]]

    to_update_index = weather.fields.index("\t\tAir Pressure")
    if weather.dataParts[to_update_index] == 0:
        weather.dataParts[to_update_index] = "800 hPa"
    elif weather.dataParts[to_update_index] == 402:
        weather.dataParts[to_update_index] = "1201 hPa or more"
    elif weather.dataParts[to_update_index] == 403:
        weather.dataParts[to_update_index] = "data N/A"
    else:
        weather.dataParts[to_update_index] = "{} hPa".format(weather.dataParts[to_update_index]+799)

    to_update_index = weather.fields.index("\t\tPressure Tendency")
    tendencies = ["steady", "decreasing", "increasing", "N/A"]
    weather.dataParts[to_update_index] = tendencies[weather.dataParts[to_update_index]]

    to_update_index = weather.fields.index("\t\tPressure Sensor Type")
    weather.dataParts[to_update_index] = enums.sensorTypes[weather.dataParts[to_update_index]]

    to_update_index = weather.fields.index("\t\tSalinity")
    if weather.dataParts[to_update_index] == 50.1:
        weather.dataParts[to_update_index] = "50.1 percent or more"
    elif weather.dataParts[to_update_index] == 50.2:
        weather.dataParts[to_update_index] = "data N/A"
    elif weather.dataParts[to_update_index] == 50.3:
        weather.dataParts[to_update_index] == "sensor N/A"
    else:
        weather.dataParts[to_update_index] = "{}%".format(weather.dataParts[to_update_index])

def updateAirGapPayload(air):
    """Interpretuje zawartości pól dla tablicy informacji o odczycie czujnika - typ Air Gap/Air Draft

    Args:
        air (airGapPayload): struktura danych dla tablicy informacji o odczycie czujnika - typ Air Gap/Air Draft
    """
    to_update_index = air.fields.index("\t\tAir Draught")
    if air.dataParts[to_update_index] == 819.1:
        air.dataParts[to_update_index] = "81.91 metres or more"
    elif air.dataParts[to_update_index] == 0:
        air.dataParts[to_update_index] == "N/A"
    else:
        air.dataParts[to_update_index] = "{} metres".format(air.dataParts[to_update_index]*0.1)

    to_update_index = air.fields.index("\t\tAir Gap")
    if air.dataParts[to_update_index] == 819.1:
        air.dataParts[to_update_index] = "81.91 metres or more"
    elif air.dataParts[to_update_index] == 0:
        air.dataParts[to_update_index] == "N/A"
    else:
        air.dataParts[to_update_index] = "{} metres".format(air.dataParts[to_update_index]*0.1)

    to_update_index = air.fields.index("\t\tAir Gap Trend")
    trends = ["steady", "rising", "falling", "N/A"]
    air.dataParts[to_update_index] = trends[air.dataParts[to_update_index]]

    to_update_index = air.fields.index("\t\tForecast Air Gap")
    if air.dataParts[to_update_index] == 819.1:
        air.dataParts[to_update_index] = "81.91 metres or more"
    elif air.dataParts[to_update_index] == 0:
        air.dataParts[to_update_index] == "N/A"
    else:
        air.dataParts[to_update_index] = "{} metres".format(air.dataParts[to_update_index]*0.1)

    to_update_index = air.fields.index("\tDay (UTC)")
    if(air.dataParts[to_update_index]) == 0:
        air.dataParts[to_update_index] = "N/A"
    to_update_index = air.fields.index("\tHour (UTC)")
    if(air.dataParts[to_update_index]) == 24:
        air.dataParts[to_update_index] = "N/A (UTC)"
    to_update_index = air.fields.index("\tMinute (UTC)")
    if(air.dataParts[to_update_index]) == 60:
        air.dataParts[to_update_index] = "N/A"    

def updateGauge(gauge):
    """Interpretuje zawartości pól dla tablicy informacji o pomiarach wskaźników

    Args:
        gauge (gauge): struktura danych dla tablicy informacji o pomiarach wskaźników
    """
    to_update_index = gauge.fields.index("\tGauge ID")
    if gauge.dataParts[to_update_index] == 0:
        gauge.dataParts[to_update_index] = "Unknown"

    to_update_index = gauge.fields.index("\tWater Level")
    if gauge.dataParts[to_update_index] == 0:
        gauge.dataParts[to_update_index] = "Unknown"
    else:
        gauge.dataParts[to_update_index] = "{} cm".format(gauge.dataParts[to_update_index])

def updateReservedSlot(slot):
    """Interpretuje zawartości pól dla tablicy zarezerwowanych slotów

    Args:
        slot (reservedSlot): struktura danych dla tablicy zarezerwowanych slotów
    """
    to_update_index = slot.fields.index("\tTime-out")
    slot.dataParts[to_update_index] = "{} minutes".format(slot.dataParts[to_update_index])