import math

def decode_u_int(fragment):
    """Konwersja do unsigned int/enum/bool dowolnej liczby bitów.

    Args:
        fragment: część wiadomości użytecznej, podanej na wejście jako ciąg binarny w formacie string
    
    Returns:
        value: Zdekodowana liczba w zapisie dziesiątkowym w formacie unsigned int
    """
    value = int(fragment, 2)
    return value


def decode_s_int(fragment):
    """Konwersja do signed int dowolnej liczby bitów.

    Args:
        fragment: Część wiadomości użytecznej, podanej na wejście jako ciąg binarny w formacie string

    Returns:
        value: Zdekodowana liczba w zapisie dziesiątkowym w formacie signed int
    """             
    byte = int(fragment, 2)
    bits = len(fragment)
    ## konwersja do zapisu dziesiątkowego i sprawdzenie, czy nie przekroczony jest próg 2^(x-1) - 1,
    # wtedy odpowiedni dobór znaków i wybór konwersji
    if byte > ((2**(bits-1)) - 1):
        value = (2**bits - byte) * (-1)
    else:
        value = byte
    return value
    

def decode_t(fragment):
    """Konwersja ciagów 6-bitowych na string w 6-bit ASCII.

    Args:
        fragment: Część wiadomości użytecznej, podanej na wejście jako ciąg binarny w formacie string

    Returns:
        value: Konkatenacja wszystkich otrzymanych poprawnie znaków 6-bit ASCII
    """
    value = ""
    bits = len(fragment)
    max = math.floor(bits/6) ## jeżeli liczba bitów we fragmencie nie jest podzielna przez 6, to zignoruj nadmiarowe bity
    i = 0
    while i < max:
        x = fragment[6*i:6*i+6]
        if x == '000000': ## jeżeli zostanie napotkana "@", to zakończ przetwarzanie
            return value
        dec_value = int(x, 2)
        ## konwersja na znaki ASCII zgodnie z dokumentacją AIVDM
        if dec_value < 32:
            six_bit_ascii = chr(dec_value + 64)
        if dec_value >= 32:
            six_bit_ascii = chr(dec_value)
        value += six_bit_ascii
        i += 1
    return value


def decode_UX(fragment, type):
    """Konwersja ciągu bitowego na format U1 i U2.

    Args:
        fragment: Część wiadomości użytecznej, podanej na wejście jako ciąg binarny w formacie string
        type: Określa typ konwersji, tzn. ilość miejsc po przecinku

    Returns:
        value: Zwraca przekonwertowany ciąg bitowy w postaci typu float
    """
    ## ochrona przed pustym stringiem
    if len(fragment) == 0:
        fragment = '0'
    number = str(int(fragment, 2))
    prefix = ""
    length = len(number)
    ## sprawdzenie czy nie trzeba dopisać dodatkowych zer
    if length - type == -1:
        value = float('.0' + number)
    if length - type > -1:
        prefix = number[0:-(type)]
        suffix = number[-(type):]
        value = float(prefix+'.'+suffix)
    return value


def decode_IX(fragment, type):
    """Konwersja ciągu bitowego na format I1, I2, I3 i I4.

    Args:
        fragment: Część wiadomości użytecznej, podanej na wejście jako ciąg binarny w formacie string
        type: Określa typ konwersji, tzn. ilość miejsc po przecinku

    Returns:
        value: Zwraca przekonwertowany ciąg bitowy w postaci typu float
    """
    sign = 0
    bits = len(fragment)
    ## ochrona przed pustym stringiem
    if len(fragment) == 0:
        fragment = '0'
        bits = 1

    ## konwersja na takiej samej zasadzie jak w decode_s_int, jednak wartość w abs() oraz zachowywana jest flaga znaku
    byte = int(fragment, 2)
    if byte > ((2**(bits-1)) - 1):
        number = (2**bits - byte)
        sign = 1
    else:
        number = byte
    number = str(number)
    length = len(number)

    ## jeżeli ciąg jest krótszy niż ilość miejsc po przecinku, dodaj odpowiednią liczbę zer
    if (length - type) == (-3):
        value = float('.000'+ number)
    if (length - type) == (-2):
        value = float('.00'+ number)
    if (length - type) == (-1):
        value = float('.0'+ number)
    if length - type > -1:
        prefix = number[0:(-type)]
        suffix = number[(-type):]
        value = float(prefix+'.'+suffix)

    ## sign - flaga znaku, która jest uwzględniana po przetworzeniu liczby do IX    
    if sign == 1:
        value = value * (-1)
    return value
    