import math
from Aggregates import arrays_aggregates
from Aggregates import message_aggregates
from Decoder import dictionaries

# specyficzne typy wiadomości
need_adjustment = ["8_6", "24", "25", "26"]
has_array = ['6_2', '6_7', '6_8', '6_9', '6_11', '7', '8_4', '8_7', '8_9', '8_10', '8_15', '20']
shorter_than_expected = {"15":88, "16":96, "21":272}
is_type_26 = ["26_00", "26_10", "26_01", "26_11"]


def decode_message(message):
    """Dekodowanie wiadomości na podstawie znajomości jej typu oraz jego ewentualnych specyficznych cech
       (np. posiadania tabel, krótszego pola tekstowego na końcu wiadomości lub podtypu zależnego od flag).

        Args:
            message: Słownik, zawierający typ (str), oraz wiadomość użyteczną w postaci ciągu binarnego (str)

        Returns:
            decoded_message: Zdekodowana wiadomość.
    """

    adjusted = ""
    if message["type"] in need_adjustment:
        adjusted = adjust_message(message)
    
    if adjusted == "unknown subtype":
        return "message data error"

    shorter_in_wild = ["24_A", "24_B"]
    length_exceptions = shorter_in_wild + list(shorter_than_expected.keys())
    if message["type"] not in list(message_aggregates.datapartsBitlengths.keys()):
        print("Nielegalny klucz: " + message["type"])
    expected_length = sum(message_aggregates.datapartsBitlengths[message["type"]])
    if (len(message["message"]) < expected_length) and (message["type"] not in length_exceptions):
        return "message data error"

    if (message["type"] in list(shorter_than_expected.keys())):
        min_length = shorter_than_expected[message["type"]]
        if len(message["message"]) < min_length:
            return "message data error"


    mainfields_bitstrings = split_to_fields(message)
    dataParts = decode_bitstrings(mainfields_bitstrings, message)

    if message["type"] in has_array:
        bin_array = extract_array(message)
        fields_array = decode_array(bin_array, message)
        decoded_message = dictionaries.msg_type_dictionary(message["type"])(dataParts, fields_array)

    else:
        decoded_message = dictionaries.msg_type_dictionary(message["type"])(dataParts)

    return decoded_message


def adjust_message(message):
    """Dostosowanie i zmiana typu na podtyp w zależności od charakteryzujących go flag.

    Args:
        message: Słownik, zawierający typ (str), oraz wiadomość użyteczną w postaci ciągu binarnego (str)
    """
    if message["type"] == '24':
        check_24 = int(message["message"][38:40], 2)
        if check_24 == 0:
            message["type"] = '24_A'
        elif check_24 == 1:
            message["type"] = '24_B'
        else:
            return "unknown subtype"

    elif message["type"] == '25' or '26':
        flags = message["message"][38:40]                        # pole flag adressed i structured
        message["type"] = str(message["type"] + '_' + flags)

    elif message["type"] == '8_6':
        check_8_6 = int(message["message"][56])                  #56 - pole wmo
        if check_8_6 == 0:
            message["type"] = '8_6_1'
        if check_8_6 == 1:
            message["type"] = '8_6_2'


def shorten_message(message):
    """Zmiana ilości pól zawartych w krotce, w zależności od długości wiadomości.

    Args:
        message: Słownik, zawierający typ (str), oraz wiadomość użyteczną w postaci ciągu binarnego (str)
    
    Returns:
        nowa_krotka: Wiadomość z ilością pól w krotce zależną od długości wiadomości.
    """
    nowa_krotka = 0 ###
    if message["type"] == "15":
        if len(message["message"]) == 88:
            nowa_krotka = message_aggregates.datapartsBitlengths[message["type"]][0:7]
        if len(message["message"]) == 110:
            nowa_krotka = message_aggregates.datapartsBitlengths[message["type"]][0:11]
        if len(message["message"]) == 160:
            nowa_krotka = message_aggregates.datapartsBitlengths[message["type"]]

    elif message["type"] == "16":
        if len(message["message"]) == 92:
            nowa_krotka = message_aggregates.datapartsBitlengths[message["type"]][0:7]
        if len(message["message"]) == 140:
            nowa_krotka = message_aggregates.datapartsBitlengths[message["type"]]

    elif message["type"] == "21":
        if len(message["message"]) < sum(message_aggregates.datapartsBitlengths[message["type"]]):
            nowa_krotka = message_aggregates.datapartsBitlengths[message["type"]][0:20]
            
    return nowa_krotka
    

def extract_20_bits(msg):
    """Wycięcie ostatnich 20 bitów z wiadomości typu 26 i przypisanie ich do nowego, następnego
       elementu w "fragment".

    Args:
        msg: Lista zawierająca ciągi binarne kolejnych elementów wiadomości
    
    Returns:
        fragment[]: Lista zawierająca ciągi binarne kolejnych elementów, z dołączonym zdekodowanym
        elementem w postaci ostatnich 20 bitów
    """
    i = 0
    fragment = []
    while i < 6:
        fragment.append(msg[i])
        i += 1
    fragment.append(msg[7][0:(len(msg[7])-20)]) ##8 element (od początku do końca stringa - 20bitów)
    decoded_radio_status = dictionaries.field_type_dictionary(msg[7][len(msg[7]):], 'u')
    fragment.append(decoded_radio_status)        
    return fragment


def split_to_fields(message):
    """Podział wiadomości użytecznej na poszczególne pola z parametrami typu AIVDM.

    Args:
        message: Słownik, zawierający typ (str), oraz wiadomość użyteczną w postaci ciągu binarnego (str)

    Returns:
        fragment: Tablica zawierająca kolejne pola z ciągami binarnymi (poszczególnych parametrów
                  wiadomości)
    """
    i = 0
    position = 0
    fragment = []
    if message["type"] in list(shorter_than_expected.keys()):
        field_count = len(shorten_message(message))
    else:
        field_count = len(message_aggregates.datapartsBitlengths[message["type"]])

    while i < field_count:
        field_bits = message_aggregates.datapartsBitlengths[message["type"]][i]
        fragment.append(message["message"][position:(field_bits + position)])
        position += field_bits
        i += 1

    if message["type"] in is_type_26: 
        fragment = extract_20_bits(fragment)

    return fragment


def decode_bitstrings(bit_strings, message):
    """Dekoduje ciągi binarne w zależności od typu.

    Args:
        bit_strings: Lista, zawierająca podzielone (względem parametru, który opisują) ciągi bitowe
                     wiadomości podstawowej
        message: Słownik, zawierający typ (str), oraz wiadomość użyteczną w postaci ciągu binarnego (str)

    Returns:
        dataParts: Lista zawierająca zdekodowane elementy wiadomości (bez tablic)
    """
    i = 0
    dataParts = []

    if message["type"] in list(shorter_than_expected.keys()):
        field_count = len(shorten_message(message))
    else:
        field_count = len(message_aggregates.datapartsBitlengths[message["type"]])

    while i < field_count:
        field_type = message_aggregates.datapartsTypes[message["type"]][i]
        
        one_decoded_field = dictionaries.field_type_dictionary(bit_strings[i], field_type)
        if one_decoded_field != 'NULL':
            dataParts.append(one_decoded_field)
        i += 1

    return dataParts


def extract_array(message):
    """Wyodrębnienie kolejnych tablic występujących w wiadomości.

    Args:
        message: Słownik, zawierający typ (str), oraz wiadomość użyteczną w postaci ciągu binarnego (str)

    Returns:
        extracted_array: Lista zawierająca kolejne tablice występujące w wiadomości
    """
    extracted_array = []
    type = message["type"]
    nr_of_array = dictionaries.array_dictionary[type]
    offset = sum(message_aggregates.datapartsBitlengths[type])
    bits_per_element_of_array = sum(arrays_aggregates.arraysDataBitlengths[nr_of_array])
    expected_length = math.floor((len(message["message"]) - offset)/bits_per_element_of_array)

    for i in range(expected_length):
        extracted_array.append(message["message"][offset:(offset + bits_per_element_of_array)])
        offset += bits_per_element_of_array

    return extracted_array


def decode_array(bin_array, message):
    """Dekodowanie kolejnych tablic występujących w wiadomości w zależności od jej typu.

    Args:
        bin_array: Lista zawierająca kolejne tablice występujące w wiadomości.
        message: Słownik, zawierający typ (str), oraz wiadomość użyteczną w postaci ciągu binarnego (str)

    Returns:
        decoded: Lista zawierająca zdekodowane tablice występujące w wiadomości.
    """
    i = 0
    k = 0
    decoded = []
    type = dictionaries.array_dictionary[message["type"]]

    if message["type"] == '6_2' or '6_8' or '6_9' or '6_11' or '7' or '8_4' or '8_10' or '8_15' or '20':
        field_count = len(bin_array)
        while i < field_count:
            decoded_part = row_of_array(type, bin_array[k])
            decoded.append(decoded_part)
            i += 1

    if message["type"] == '8_9':
        field_count = len(bin_array)
        while i < field_count:
            type_of_report = recognize_what_type(4, bin_array[i], type)
            decoded_part = row_of_array(type, bin_array[i])
            decoded.append(decoded_part)
            sensor_payload_array = row_of_array(type_of_report, bin_array[k])
            decoded.append(sensor_payload_array)
            i += 1

    if message["type"] == '6_7' or '8_7':
        while i < len(bin_array):
            type_of_shape = recognize_what_type(3, bin_array[i], message["type"])
            decoded_part = row_of_array(type_of_shape, bin_array[i])
            decoded.append(decoded_part)
            i += 0

    return decoded


def recognize_what_type(numb_of_type_bits, array, type):
    """Rozpoznawanie typów tablic (typów reportów lub kształtów).

    Args:
        numb_of_type_bits: Ilość bitów określających typ tablicy
        array: Tablica, której typ jest określany
        type: Typ wiadomości

    Returns:
        recognized_type: Rozpoznany typ tablicy
    """

    value = ""
    j = 0
    position = 0
    recognized_type = 0

    while j < numb_of_type_bits:
        value += str(array[position])
        position += 1
        j += 1

    if type == 15:
        recognized_type = dictionaries.report_dictionary[value]
    if type == 2:
        recognized_type = dictionaries.shape_dictionary[value]

    return recognized_type


def row_of_array(type, extracted_array):
    """Dekodowanie kolejnych obiektów tablicy występującej w wiadomości.

    Args:
        type: Typ tablicy
        extracted_array: Tablica wyodrębniona z wiadomości

    Returns:
        array_object: Zdekodowana lista obiektów tablicy
    """

    i = 0
    position = 0
    nr_of_waypoints = 4
    nr_of_vertices = 4
    decoded_row = []
    loop_counter = len(arrays_aggregates.arraysDataBitlengths[type])
    if (type == 15 | 16 | 17 | 18 | 19 | 20 | 21 | 22 | 23 | 24 | 25 | 26):
        position = 0
    if (type == 2 | 3 | 4 | 5 | 7 | 9):
        position = 3

    while i < loop_counter:
        field_bits = arrays_aggregates.arraysDataBitlengths[type][i]
        field_type = arrays_aggregates.arraysDataTypes[type][i]
        endgame_field = dictionaries.field_type_dictionary(extracted_array[position:(field_bits + position)], field_type)

        if endgame_field != 'NULL':
            decoded_row.append(endgame_field)
        position += field_bits

        l = 0
        if type == 5:
            for m in range(nr_of_waypoints):
                while l < 2:
                    decoded_part = row_of_array((type + 1), extracted_array)
                    decoded_row.append(decoded_part)
                    l += 1
        if type == 7:
            for m in range(nr_of_vertices):
                while l < 2:
                    decoded_part = row_of_array((type + 1), extracted_array)
                    decoded_row.append(decoded_part)
                    l += 1
        i += 1

    array_object = dictionaries.array_type_dictionary(type)(decoded_row)

    return array_object
