import os.path
import codecs
import shutil
from datetime import datetime
import time
import math

def printMessage(message):
    """Drukuje zawarte w wiadomości informacje w terminalu i do pliku

    Args:
        message: struktura danych wiadomości
    """
    filename = str(message.dataParts[message.fields.index("Source MMSI")]) + ".txt"
    topDir = "..\AIS_messages"
    messageDir = message.name
    if not os.path.exists(topDir):
        os.mkdir(topDir)
    if hasattr(message, 'subname'):
        messageSubDir = message.subname    
        filePath = os.path.join(topDir, messageDir, messageSubDir, filename)
        try:
            os.mkdir(os.path.join(topDir, messageDir))
            os.mkdir(os.path.join(topDir, messageDir, messageSubDir))
        except Exception:
            pass
    else:
        filePath = os.path.join(topDir, messageDir, filename)
        try:
            os.mkdir(os.path.join(topDir, messageDir))
        except Exception:
            pass
    
    if os.path.isfile(filePath):
        with open(filePath, 'a') as file_object:
            file_object.write("\n==================================================================================\n\n") 
            for field, value in zip(message.fields, message.dataParts):
                file_object.write(field + ": " + str(value) + "\n")        
    else:
        with open(filePath, 'w') as file_object:
            for field, value in zip(message.fields, message.dataParts):
                file_object.write(field + ": " + str(value) + "\n")

def printStats(stats, start_time):
    """Drukuje zawarte statystyki wiadomości w terminalu i do pliku

    Args:
        stats (dict): Zestaw liczników dla poszczególnych statystyk
        start_time (int): Timestamp początku działania programu
    """
    print("Wszystkich wiadomosci: {}".format(stats["all"]))
    print("Wiadomości pojedynczych: {ile} ({proc}%)".format(ile=stats["single"], proc=round(100*stats["single"]/stats["all"],2)))
    print("Wiadomości podwójnych: {ile} ({proc}%)".format(ile=stats["double"], proc=round(100*stats["double"]/stats["all"],2)))
    print("Wiadomości z błędną sumą kontrolną: {ile} ({proc}%)".format(ile=stats["defective"], proc=round(100*stats["defective"]/stats["all"],2)))
    print("Wiadomości bez zawartości: {ile} ({proc}%)".format(ile=stats["empty"], proc=round(100*stats["empty"]/stats["all"],2)))
    for i in range(len(stats["types"])):
        print("Wiadomości typu {}".format(i+1) +": {ile} ({proc}%)".format(ile=stats["types"][i], proc=round(100*stats["types"][i]/stats["all"],2)))
    
    now = datetime.now()
    current_time = now.strftime("%H:%M:%S")
    print("\nCzas wykonania przetwarzania:", current_time)    
    
    processing_time = time.time() - start_time
    processing_hours = round(math.floor(processing_time/(60*60)))
    processing_minutes = round(math.floor((processing_time - processing_hours*60*60)/60))
    processing_seconds = round(processing_time - processing_hours*60*60 - processing_minutes*60)
    print("Czas przetwarzania: {hh}:{mm}:{ss}".format(hh=processing_hours, mm=processing_minutes, ss=processing_seconds))

    filename = "..\stats.txt"
    with codecs.open(filename, 'w', "utf-8") as file_object:
        file_object.write("Wszystkich wiadomosci: {}".format(stats["all"]) + "\n")
        file_object.write("Wiadomości pojedynczych: {ile} ({proc}%)".format(ile=stats["single"], proc=round(100*stats["single"]/stats["all"],2)) + "\n")
        file_object.write("Wiadomości podwójnych: {ile} ({proc}%)".format(ile=stats["double"], proc=round(100*stats["double"]/stats["all"],2)) + "\n")
        file_object.write("Wiadomości z błędną sumą kontrolną: {ile} ({proc}%)".format(ile=stats["defective"], proc=round(100*stats["defective"]/stats["all"],2)) + "\n")
        file_object.write("Wiadomości bez zawartości: {ile} ({proc}%)".format(ile=stats["empty"], proc=round(100*stats["empty"]/stats["all"],2)) + "\n")
        for i in range(len(stats["types"])):
            file_object.write("Wiadomości typu {}".format(i+1) +": {ile} ({proc}%)".format(ile=stats["types"][i], proc=round(100*stats["types"][i]/stats["all"],2)) + "\n")
        file_object.write("\nCzas wykonania przetwarzania = {}\n".format(current_time))
        file_object.write("Czas przetwarzania: {hh}:{mm}:{ss}".format(hh=processing_hours, mm=processing_minutes, ss=processing_seconds))

def delete_ais_files():
    """Usuwa pliki ze zdekodowanymi wiadomościami AIS
    """
    topDir = "..\AIS_messages"
    if os.path.exists(topDir):
        try:
            shutil.rmtree(topDir)
        except:
            print('Error while deleting directory')